@@ -280,7 +280,9 @@ async def test_warn_close(aconn, recwarn, gc_collect):
     await cur.execute("select generate_series(1, 10) as bar")
     del cur
     gc_collect()
-    assert ".close()" in str(recwarn.pop(ResourceWarning).message)
+    msg = str(recwarn.pop(ResourceWarning).message)
+    assert aconn.server_cursor_factory.__name__ in msg
+    assert ".close()" in msg
 
 
 async def test_execute_reuse(aconn):
@@ -437,6 +439,7 @@ async def test_iter(aconn):
 
 async def test_iter_rownumber(aconn):
     async with aconn.cursor("foo") as cur:
+        cur.itersize = 2
         await cur.execute(ph(cur, "select generate_series(1, %s) as bar"), (3,))
         async for row in cur:
             assert cur.rownumber == row[0]
@@ -456,6 +459,14 @@ async def test_itersize(aconn, acommands):
             assert "fetch forward 2" in cmd.lower()
 
 
+async def test_next(aconn):
+    async with aconn.cursor() as cur:
+        await cur.execute("select 1")
+        assert await anext(cur) == (1,)
+        with pytest.raises(StopAsyncIteration):
+            await anext(cur)
+
+
 async def test_cant_scroll_by_default(aconn):
     cur = aconn.cursor("tmp")
     assert cur.scrollable is None
@@ -576,3 +587,9 @@ async def test_row_maker_returns_none(aconn):
         assert await alist(cur) == recs
         stream = cur.stream(query)
         assert await alist(stream) == recs
+
+
+async def test_results_after_execute(aconn):
+    async with aconn.cursor("test") as cur:
+        await cur.execute("select 1")
+        assert await alist(cur.results()) == [cur]
